==> sale-1.5.88-05.jar: revenue/sqls/revenue/common/singleTable_User.sql <==
select   files.f_user_id  f_user_id,   --表编号
       files.f_userinfo_id  f_userinfo_id, --用户唯一id号
       info.f_userinfo_code, -- 显示的用户编号
       files.f_totalsplit_type,		-- 总分表类型
       files.f_share_ratio,			-- 承担比率
       info.f_price_id,             --气价编号
       stairprice.id  f_stairprice_id,      --气价表主键id
       gasbrand.f_meter_type  f_meter_classify,       --气表分类
       info.f_contract_id,			 --合同编号
       files.f_position,               --表安装位置
       files.f_meternumber,            --表号
       files.f_metertitles,            --表封号
       files.f_card_id,                --卡号
       files.f_aroundmeter,            --左 右 表
       files.f_times,                  --写卡次数
       files.f_balance_amount,       -- 表具剩余金额
       files.f_balance_gas,          -- 表具剩余气量
       files.f_whether_hairpin,        --是否发卡
       files.f_inputtor,               --抄表 员
       info.f_user_state,           --用户状态
       files.f_remanent_gas,         --剩余补气量
       info.f_user_name,            --用户姓名
       info.f_balance,          	 --用户账户结余
       info.f_cost_type,		   	 --缴费类型
       info.f_residential_area, 	 --小区
       info.f_address,              --地址
       info.f_room,             	 --门牌号
       info.f_street,  			 --街道
       info.f_unit,  				 --单元号
       info.f_building,  			 --楼号
       info.f_floor,  				 --楼层
       info.f_credentials,			 --证件类型
       files.version,                --版本号
       files.f_card_password,        --卡密码
       info.f_idnumber,             --证件号码
       info.f_user_phone,   		 --用户电话
       info.f_user_type,            --用户类型
       info.f_gasproperties,		 --用气性质
       files.f_meterid,              --用户号
       info.version userinfo_version,       --版本
       files.f_initial_base,	     --表初始底数
       info.f_createfile_date,      --建档日期
       files.f_gasbrand_id,			 --表品牌id
       files.f_gasmodel_id,			 --表型号id
       files.f_table_state,          --表状态
       gasbrand.f_isdecimal,			--是否支持小数
       gasbrand.f_collection_type,		--气表支持支付方式
       gasbrand.f_police_gas,           --报警气量
       gasbrand.f_topup_ceil, 			 --充值上限
       gasbrand.f_overdr_lines, 		 --透支额度
       gasbrand.f_alias,				 --别名
       gasbrand.f_meter_brand, 		 --气表品牌
       gasgmodel.f_meter_style,			 --气表型号
       gasgmodel.f_coding,
       gasgmodel.f_billing,         -- 结算方式
       gasgmodel.f_calculation,     -- 计费方式
       gasbrand.f_manufacturers,		 --气表厂家
       gasbrand.f_meter_type,			 --气表类型
       files.f_meter_base,   			 --气表底数
       files.f_total_gas,
       files.f_total_fee,				 --表累购金额
       stairprice.f_price_type,	 		 --气价类型
       stairprice.f_price_name,    --气价名称
       info.f_paper_type,			 --票据类型
       info.f_comments,               --备注信息
       stairprice.id id,
       case
		 when files.f_table_state='停用' then '停用'
		 when files.f_whether_hairpin='未发' and gasbrand.f_meter_type like '%卡表'  then '未发'
		 when v.f_operat_type='补卡' then '补卡'
		 when v.f_operat_type= '换表' then '换表'
		 --when v.f_operat_type= '换表补气' then '换表补气'
		 when o.f_whether_pay='否' then '超用'
 	   else '正常' end f_states
from
   t_userfiles files
   inner join
   t_userinfo info  on files.f_userinfo_id=info.f_userinfo_id
   left join
   (select * from t_stairprice where getdate()>=f_perform_date
   and getdate()<=f_end_date  and f_state = '有效') stairprice
   on info.f_price_id=stairprice.f_price_id and info.f_filialeids = stairprice.f_filialeids
   left join
   t_gasbrand  gasbrand on files.f_gasbrand_id=gasbrand.id
   left join
   t_gasmodel  gasgmodel  on files.f_gasmodel_id=gasgmodel.id
   left join
  (select * from t_overuse where f_whether_pay = '否' and f_overuse_state = '有效') o  on files.f_user_id=o.f_user_id
  left join
   (SELECT r1.id,r1.f_operat_type,r1.f_user_id
			FROM
				(SELECT  MAX (id) AS id FROM t_record
				 WHERE f_state = '有效' AND (f_operat_type in ('卡表收费','换表','补卡','发卡售气','超用收费','卡表超用') or  f_operat_type like '%补气%')
				GROUP BY f_user_id
				) r
			INNER JOIN t_record r1 ON r.id = r1.id
	) v on v.f_user_id=files.f_user_id
where   {condition} and info.f_user_state != '销户'
order by {orderitem}

==> sale-1.5.88-09.jar: revenue/sqls/revenue/common/singleTable_User.sql <==
select   files.f_user_id  f_user_id,   --表编号
       files.f_userinfo_id  f_userinfo_id, --用户唯一id号
       info.f_userinfo_code, -- 显示的用户编号
       files.f_totalsplit_type,		-- 总分表类型
       files.f_share_ratio,			-- 承担比率
       info.f_price_id,             --气价编号
       stairprice.id  f_stairprice_id,      --气价表主键id
       gasbrand.f_meter_type  f_meter_classify,       --气表分类
       info.f_contract_id,			 --合同编号
       files.f_position,               --表安装位置
       files.f_meternumber,            --表号
       files.f_metertitles,            --表封号
       files.f_card_id,                --卡号
       files.f_aroundmeter,            --左 右 表
       isnull(files.f_times,0) f_times,                  --写卡次数
       files.f_balance_amount,       -- 表具剩余金额
       files.f_balance_gas,          -- 表具剩余气量
       files.f_whether_hairpin,        --是否发卡
       files.f_inputtor,               --抄表 员
       info.f_user_state,           --用户状态
       files.f_remanent_gas,         --剩余补气量
       info.f_user_name,            --用户姓名
       info.f_balance,          	 --用户账户结余
       info.f_cost_type,		   	 --缴费类型
       info.f_residential_area, 	 --小区
       info.f_address,              --地址
       info.f_room,             	 --门牌号
       info.f_street,  			 --街道
       info.f_unit,  				 --单元号
       info.f_building,  			 --楼号
       info.f_floor,  				 --楼层
       info.f_credentials,			 --证件类型
       files.version,                --版本号
       files.f_card_password,        --卡密码
       info.f_idnumber,             --证件号码
       info.f_user_phone,   		 --用户电话
       info.f_user_type,            --用户类型
       info.f_gasproperties,		 --用气性质
       files.f_meterid,              --用户号
       info.version userinfo_version,       --版本
       files.f_initial_base,	     --表初始底数
       info.f_createfile_date,      --建档日期
       files.f_gasbrand_id,			 --表品牌id
       files.f_gasmodel_id,			 --表型号id
       files.f_table_state,          --表状态
       gasbrand.f_isdecimal,			--是否支持小数
       gasbrand.f_collection_type,		--气表支持支付方式
       gasbrand.f_police_gas,           --报警气量
       gasbrand.f_topup_ceil, 			 --充值上限
       gasbrand.f_overdr_lines, 		 --透支额度
       gasbrand.f_alias,				 --别名
       gasbrand.f_meter_brand, 		 --气表品牌
       gasgmodel.f_meter_style,			 --气表型号
       gasgmodel.f_coding,
       gasgmodel.f_billing,         -- 结算方式
       gasgmodel.f_calculation,     -- 计费方式
       gasbrand.f_manufacturers,		 --气表厂家
       gasbrand.f_meter_type,			 --气表类型
       files.f_meter_base,   			 --气表底数
       files.f_total_gas,
       files.f_total_fee,				 --表累购金额
       stairprice.f_price_type,	 		 --气价类型
       stairprice.f_price_name,    --气价名称
       info.f_paper_type,			 --票据类型
       info.f_comments,               --备注信息
       stairprice.id id,
       case
		 when files.f_table_state='停用' then '停用'
		 when files.f_whether_hairpin='未发' and gasbrand.f_meter_type like '%卡表'  then '未发'
		 when v.f_operat_type='补卡' then '补卡'
		 when v.f_operat_type= '换表' then '换表'
		 --when v.f_operat_type= '换表补气' then '换表补气'
		 when o.f_whether_pay='否' then '超用'
 	   else '正常' end f_states
from
   t_userfiles files
   inner join
   t_userinfo info  on files.f_userinfo_id=info.f_userinfo_id
   left join
   (select * from t_stairprice where getdate()>=f_perform_date
   and getdate()<=f_end_date  and f_state = '有效') stairprice
   on info.f_price_id=stairprice.f_price_id and info.f_filialeids = stairprice.f_filialeids
   left join
   t_gasbrand  gasbrand on files.f_gasbrand_id=gasbrand.id
   left join
   t_gasmodel  gasgmodel  on files.f_gasmodel_id=gasgmodel.id
   left join
  (select * from t_overuse where f_whether_pay = '否' and f_overuse_state = '有效') o  on files.f_user_id=o.f_user_id
  left join
   (SELECT r1.id,r1.f_operat_type,r1.f_user_id
			FROM
				(SELECT  MAX (id) AS id FROM t_record
				 WHERE f_state = '有效' AND (f_operat_type in ('卡表收费','换表','补卡','发卡售气','超用收费','卡表超用') or  f_operat_type like '%补气%')
				GROUP BY f_user_id
				) r
			INNER JOIN t_record r1 ON r.id = r1.id
	) v on v.f_user_id=files.f_user_id
where   {condition} and info.f_user_state != '销户'
order by {orderitem}
